--    Copyright (C) 2004 by neuron                                          
--    aagaande@gmail.com                                            
--                                                                          
--    This program is free software; you can redistribute it and--or modify  
--    it under the terms of the GNU General Public License as published by  
--    the Free Software Foundation; either version 2 of the License, or     
--    (at your option) any later version.                                   
--                                                                          
--    This program is distributed in the hope that it will be useful,       
--    but WITHOUT ANY WARRANTY; without even the implied warranty of        
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         
--    GNU General Public License for more details.                          
--                                                                          
--    You should have received a copy of the GNU General Public License     
--    along with this program; if not, write to the                         
--    Free Software Foundation, Inc.,                                       
--    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. 

local options = {
		type='group',
		args = {
	         resetPos = {
	            type = 'execute',
	            name = 'Reset position of minion',
	            desc = 'This is incase you lost it',
	            func = function()
	            	nQuestLogFrame:ClearAllPoints()
	            	nQuestLogFrame:SetPoint("CENTER",0,0)
	            	nQuestLog:SavePosition()
	            	nQuestLog:SetPosition()
	            	nQuestLog.db.profile["trackerLocked"] = false
	            end
	        },
	         resetProfile = {
	            type = 'execute',
	            name = 'Reset Profile',
	            desc = 'This will reset the current profile',
	            order = 500,
	            func = function()
	            	nQuestLog:ResetDB("profile")
	            	nQuestLogFrame:ClearAllPoints()
	            	nQuestLogFrame:SetPoint("CENTER",0,0)
	            	nQuestLog:SavePosition()
	            	nQuestLog:SetPosition()
	            	nQuestLog:RefreshTracker()
	            end
	        },
	         toggleVisible = {
	            type = 'toggle',
	            name = 'Minion Visible',
	            desc = 'Note that minion will not show if your not tracking any quests.',
	            get = function()
	            	return nQuestLog.db.char["visible"]
	            end,
	            set = function(v)
	            	nQuestLog.db.char["visible"] = v
	            	nQuestLog:ToggleVisible(v)
	            end
	        },
	        spacer = {
	        	type = 'header',
	        	name = ' ',
	        	order = 110,
	        },
	        settings = {
	        	type = 'group',
	        	order = 90,
	        	name = 'Settings',
	        	desc = 'This needs work, I know',
	        	args = {}
	        }
		}
	}
	
local function ToggleMenu(data)
	local func_Get,func_Set
	
	if (data.type == "toggle" or data.type == "range" or data.type == "text") then
		func_Get = function()
			if (data.reversed) then
				return not nQuestLog.db.profile[data.variable]
			end
			return nQuestLog.db.profile[data.variable]
		end
		func_Set = function(v)
			if (data.reversed) then
				v = not v
			end
			nQuestLog.db.profile[data.variable] = v
			nQuestLog:RefreshTracker()
			
			-- Custom stuff needed for only few things:
			if (data.variable == "width") then
				-- This refreshes width:
				nQuestLog:ToggleVisible(true)
			elseif (data.variable == "trackerGrowUp") then
				nQuestLog:SavePosition()
				nQuestLog:SetPosition()
			end
		end
	end
	
	return func_Get,func_Set	
end

local AceProfile = {
	positionBottom = -1,
	positionLeft = -1,
	positionTop = -1,
}
local settingsTable = {
	-- This table is only used to generate AceProfile and the menu to change it
	{ name="Main settings", type="header", variable="MainHeader" },
	{ name="Lock minion", type="toggle", desc="Lock the minion to avoid dragging (drag by pulling top left)", variable="trackerLocked", value=false },
	
	{ name="Quest", type="group" },
	{ name="Show new quests", type="toggle", desc="Auto show new quests in minion", variable="trackNewQuests", value=true },
	{ name="Show quest when looting questitem", type="toggle", desc="Auto show hidden quests when you loot a quest item for it", variable="trackWhenLooting", value=true },
	
	-- Quest objective tracking related
	{ name="Quest objectives", type="group" },
	{ name="Hide All Objectives", type="toggle", desc="Hide all quest objectives by default", variable="hideAllObjectives", value=true },
	{ name="Hide Completed Objectives", type="toggle", desc="Hide completed objectives", variable="hideCompletedObjectives", value=true },
	

	{ name="Layouts", type="header", variable="LayoutHeader",menuParent=options.args.settings.args  },
	
	-- Layout stuff:
		{ name="Minion layout", type="group" },
		{ name="Grow upwards", type="toggle", desc="Grow minion up", variable="trackerGrowUp", value=false },
		{ name="Width", type="range", desc="Set width of frame", variable="width", value=266, min=50,max=500 },
		{ name="Fontsize", type="range", desc="Change font size for minion", variable="fontSize", value=14, min=1,max=25,step=1 },
	
		--Zone Related:
		{ name="Zone layout", type="group" },
		{ name="Show Visible/Total quests for a zone", type="toggle", desc="Shows <Zone> with X/X Visible", variable="showZoneVisibleStatus", value=false },
		{ name="Show empty zones", type="toggle", desc="Show hidden zones where you are not tracking any quests", variable="showEmptyZones", value=true },
		{ name="Show Zone level", type="toggle", desc="Show zone level", variable="showZoneLevel", value=true },
		{ name="Padding", type="range", desc="Change padding between zones", variable="zonePadding", value=0, min=0,max=10,step=1 },
		
		--Quest Related:
		{ name="Quest layout", type="group" },
		{ name="Show Quest Progress", type="toggle", desc="Show quest progress (1/7 items total)", variable="showQuestProgress", value=true },
		{ name="Padding", type="range", desc="Change padding between quests", variable="questPadding", value=0, min=0,max=10,step=1 },
		
		--Quest objectives related:
		{ name="Quest objectives layout", type="group" },
		{ name="Show Description when no objectives", type="toggle", desc="Show small quest description when no progress is available", variable="showShortWhenNoObjectives", value=true },
}
	
-- Make options menu for all settings:
local function MakeAllSettings()
	local menuParent = options.args.settings.args
	for i,data in ipairs(settingsTable) do
		local func_Get,func_Set = ToggleMenu(data)
	
		-- First add menu
		local strName = data.name
		if (data.type ~= "header") then
			strName = "  " .. strName
		end
		
		if (data.type == "group") then
			menuParent = options.args.settings.args
			data.desc = strName .. " settings"
			data.variable = data.name
			data.args = {}
		end
		
		if (data.menuParent) then
			menuParent = data.menuParent
		end
		
		menuParent[data.name] = {
	        type = data.type,
	        name = strName,
	        desc = data.desc, 
	        order = i,
	        get = func_Get,
	        set = func_Set,
	        min = data["min"],
	        max = data["max"],
	        step = data["step"],
	        isPercent = data["isPercent"],
	        validate = data["validate"],
	        args = data.args,
	        disabled = data.disabled,
		}
		
		if (data.type == "group") then
			menuParent = menuParent[data.variable].args
		end
		
		--Then add us to the RegisterDefaults db.
		AceProfile[data.variable] = data.value
	end
	
	settingsTable = nil
end

MakeAllSettings()


nQuestLog:RegisterDB("nQuestLogDB")
nQuestLog:RegisterDefaults('profile', AceProfile)

nQuestLog:RegisterDefaults('char', {
	visible = true,
	watchedQuests = {},
	watchedObjectives = {},
	hiddenZones = {},
})

nQuestLog.mainMenu = options
